@@ -451,4 +451,26 @@ class ChemInformatics(object):
             smarts
         )
 
-        return visualizer.get_image()
\ No newline at end of file
+        return visualizer.get_image()
+
+    @staticmethod
+    def create_scaffold_graph(node_key):
+
+        '''
+
+        Create a Scaffold Graph of a Node Key
+
+        Arguments:
+            node_key (String): The Node Key
+
+        Returns:
+            gc_sg_adapter (Object): Adapter Object
+
+        '''
+
+        from global_chem_extensions.cheminformatics.applications.scaffold_graph import ScaffoldGraphAdapter
+
+        gc_sg_adapter = ScaffoldGraphAdapter(node_key)
+
+        return gc_sg_adapter
+
